####
punx
####

Python Utilities for NeXus HDF5 files: validation, structure, hierarchy

* Validation of NeXus NXDL files
* Validation of NeXus HDF5 data files
* Display of NeXus HDF5 data file structure
* Display of NeXus base class hierarchy (stretch goal, graphical output)

NOTE: project is under initial construction

:author:    Pete R. Jemian
:email:     prjemian@gmail.com
:copyright: 2016, Pete R. Jemian
:license:   Creative Commons Attribution 4.0 International Public License (see *LICENSE.txt*)
:URL:       http://punx.readthedocs.io
:git:       https://github.com/prjemian/punx
:PyPI:      https://pypi.python.org/pypi/punx/ 
:TODO list: https://github.com/prjemian/punx/issues
